part of pointpos_api.api;



class CustomerApi {
  final ApiClient apiClient;

  CustomerApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create Customer with HTTP info returned
  ///
  /// Create Customer
  Future<Response> createCustomerWithHttpInfo(String authorization, String xAPIKey, Customer body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/customer".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Create Customer
  ///
  /// Create Customer
  Future<Customer> createCustomer(String authorization, String xAPIKey, Customer body) async {
    Response response = await createCustomerWithHttpInfo(authorization, xAPIKey, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Customer') as Customer;
    } else {
      return null;
    }
  }

  /// Delete Customer By ID with HTTP info returned
  ///
  /// Delete Customer By ID
  Future deleteCustomerByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/customer/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Delete Customer By ID
  ///
  /// Delete Customer By ID
  Future deleteCustomerByID(String authorization, String xAPIKey, String id) async {
    Response response = await deleteCustomerByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get Customer List with HTTP info returned
  ///
  /// Get Customer  List
  Future<Response> findCustomerWithHttpInfo(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }

    // create path and map variables
    String path = "/customer".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(offset != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "offset", offset));
    }
    if(sort != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if(direction != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "direction", direction));
    }
    if(filter != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("multi", "filter", filter));
    }
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Customer List
  ///
  /// Get Customer  List
  Future<List<Customer>> findCustomer(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Response response = await findCustomerWithHttpInfo(authorization, xAPIKey,  limit: limit, offset: offset, sort: sort, direction: direction, filter: filter );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Customer>') as List).map((item) => item as Customer).toList();
    } else {
      return null;
    }
  }

  /// Get Customer By ID with HTTP info returned
  ///
  /// Get Customer By ID
  Future<Response> getCustomerByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/customer/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Customer By ID
  ///
  /// Get Customer By ID
  Future<Customer> getCustomerByID(String authorization, String xAPIKey, String id) async {
    Response response = await getCustomerByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Customer') as Customer;
    } else {
      return null;
    }
  }

  /// Update Customer By ID with HTTP info returned
  ///
  /// Update [object Object] By ID
  Future<Response> updateCustomerByIDWithHttpInfo(String authorization, String xAPIKey, String id, Customer body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/customer/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Update Customer By ID
  ///
  /// Update [object Object] By ID
  Future<Customer> updateCustomerByID(String authorization, String xAPIKey, String id, Customer body) async {
    Response response = await updateCustomerByIDWithHttpInfo(authorization, xAPIKey, id, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Customer') as Customer;
    } else {
      return null;
    }
  }

}
