part of pointpos_api.api;



class IngredientApi {
  final ApiClient apiClient;

  IngredientApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create Ingredient with HTTP info returned
  ///
  /// Create Ingredient
  Future<Response> createIngredientWithHttpInfo(String authorization, String xAPIKey, Ingredient body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/ingredient".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Create Ingredient
  ///
  /// Create Ingredient
  Future<Ingredient> createIngredient(String authorization, String xAPIKey, Ingredient body) async {
    Response response = await createIngredientWithHttpInfo(authorization, xAPIKey, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Ingredient') as Ingredient;
    } else {
      return null;
    }
  }

  /// Delete Ingredient By ID with HTTP info returned
  ///
  /// Delete Ingredient By ID
  Future deleteIngredientByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/ingredient/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Delete Ingredient By ID
  ///
  /// Delete Ingredient By ID
  Future deleteIngredientByID(String authorization, String xAPIKey, String id) async {
    Response response = await deleteIngredientByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get Ingredient List with HTTP info returned
  ///
  /// Get Ingredient  List
  Future<Response> findIngredientWithHttpInfo(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }

    // create path and map variables
    String path = "/ingredient".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(offset != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "offset", offset));
    }
    if(sort != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if(direction != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "direction", direction));
    }
    if(filter != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("multi", "filter", filter));
    }
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Ingredient List
  ///
  /// Get Ingredient  List
  Future<List<Ingredient>> findIngredient(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Response response = await findIngredientWithHttpInfo(authorization, xAPIKey,  limit: limit, offset: offset, sort: sort, direction: direction, filter: filter );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Ingredient>') as List).map((item) => item as Ingredient).toList();
    } else {
      return null;
    }
  }

  /// Get Ingredient By ID with HTTP info returned
  ///
  /// Get Ingredient By ID
  Future<Response> getIngredientByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/ingredient/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Ingredient By ID
  ///
  /// Get Ingredient By ID
  Future<Ingredient> getIngredientByID(String authorization, String xAPIKey, String id) async {
    Response response = await getIngredientByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Ingredient') as Ingredient;
    } else {
      return null;
    }
  }

  /// Update Ingredient By ID with HTTP info returned
  ///
  /// Update [object Object] By ID
  Future<Response> updateIngredientByIDWithHttpInfo(String authorization, String xAPIKey, String id, Ingredient body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/ingredient/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Update Ingredient By ID
  ///
  /// Update [object Object] By ID
  Future<Ingredient> updateIngredientByID(String authorization, String xAPIKey, String id, Ingredient body) async {
    Response response = await updateIngredientByIDWithHttpInfo(authorization, xAPIKey, id, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Ingredient') as Ingredient;
    } else {
      return null;
    }
  }

}
