part of pointpos_api.api;



class ItemApi {
  final ApiClient apiClient;

  ItemApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create Item with HTTP info returned
  ///
  /// Create Item
  Future<Response> createItemWithHttpInfo(String authorization, String xAPIKey, Item body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/item".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Create Item
  ///
  /// Create Item
  Future<Item> createItem(String authorization, String xAPIKey, Item body) async {
    Response response = await createItemWithHttpInfo(authorization, xAPIKey, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Item') as Item;
    } else {
      return null;
    }
  }

  /// Delete Item By ID with HTTP info returned
  ///
  /// Delete Item By ID
  Future deleteItemByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/item/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Delete Item By ID
  ///
  /// Delete Item By ID
  Future deleteItemByID(String authorization, String xAPIKey, String id) async {
    Response response = await deleteItemByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get Item List with HTTP info returned
  ///
  /// Get Item  List
  Future<Response> findItemWithHttpInfo(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }

    // create path and map variables
    String path = "/item".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(offset != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "offset", offset));
    }
    if(sort != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if(direction != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "direction", direction));
    }
    if(filter != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("multi", "filter", filter));
    }
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Item List
  ///
  /// Get Item  List
  Future<List<Item>> findItem(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Response response = await findItemWithHttpInfo(authorization, xAPIKey,  limit: limit, offset: offset, sort: sort, direction: direction, filter: filter );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Item>') as List).map((item) => item as Item).toList();
    } else {
      return null;
    }
  }

  /// Get Item By ID with HTTP info returned
  ///
  /// Get Item By ID
  Future<Response> getItemByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/item/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Item By ID
  ///
  /// Get Item By ID
  Future<Item> getItemByID(String authorization, String xAPIKey, String id) async {
    Response response = await getItemByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Item') as Item;
    } else {
      return null;
    }
  }

  /// Update Item By ID with HTTP info returned
  ///
  /// Update [object Object] By ID
  Future<Response> updateItemByIDWithHttpInfo(String authorization, String xAPIKey, String id, Item body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/item/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Update Item By ID
  ///
  /// Update [object Object] By ID
  Future<Item> updateItemByID(String authorization, String xAPIKey, String id, Item body) async {
    Response response = await updateItemByIDWithHttpInfo(authorization, xAPIKey, id, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Item') as Item;
    } else {
      return null;
    }
  }

}
