part of pointpos_api.api;



class SupplierApi {
  final ApiClient apiClient;

  SupplierApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create Supplier with HTTP info returned
  ///
  /// Create Supplier
  Future<Response> createSupplierWithHttpInfo(String authorization, String xAPIKey, Supplier body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/supplier".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Create Supplier
  ///
  /// Create Supplier
  Future<Supplier> createSupplier(String authorization, String xAPIKey, Supplier body) async {
    Response response = await createSupplierWithHttpInfo(authorization, xAPIKey, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Supplier') as Supplier;
    } else {
      return null;
    }
  }

  /// Delete Supplier By ID with HTTP info returned
  ///
  /// Delete Supplier By ID
  Future deleteSupplierByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/supplier/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Delete Supplier By ID
  ///
  /// Delete Supplier By ID
  Future deleteSupplierByID(String authorization, String xAPIKey, String id) async {
    Response response = await deleteSupplierByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get Supplier List with HTTP info returned
  ///
  /// Get Supplier  List
  Future<Response> findSupplierWithHttpInfo(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }

    // create path and map variables
    String path = "/supplier".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(offset != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "offset", offset));
    }
    if(sort != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if(direction != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "direction", direction));
    }
    if(filter != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("multi", "filter", filter));
    }
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Supplier List
  ///
  /// Get Supplier  List
  Future<List<Supplier>> findSupplier(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Response response = await findSupplierWithHttpInfo(authorization, xAPIKey,  limit: limit, offset: offset, sort: sort, direction: direction, filter: filter );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Supplier>') as List).map((item) => item as Supplier).toList();
    } else {
      return null;
    }
  }

  /// Get Supplier By ID with HTTP info returned
  ///
  /// Get Supplier By ID
  Future<Response> getSupplierByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/supplier/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Supplier By ID
  ///
  /// Get Supplier By ID
  Future<Supplier> getSupplierByID(String authorization, String xAPIKey, String id) async {
    Response response = await getSupplierByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Supplier') as Supplier;
    } else {
      return null;
    }
  }

  /// Update Supplier By ID with HTTP info returned
  ///
  /// Update [object Object] By ID
  Future<Response> updateSupplierByIDWithHttpInfo(String authorization, String xAPIKey, String id, Supplier body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/supplier/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Update Supplier By ID
  ///
  /// Update [object Object] By ID
  Future<Supplier> updateSupplierByID(String authorization, String xAPIKey, String id, Supplier body) async {
    Response response = await updateSupplierByIDWithHttpInfo(authorization, xAPIKey, id, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Supplier') as Supplier;
    } else {
      return null;
    }
  }

}
