part of pointpos_api.api;



class TableApi {
  final ApiClient apiClient;

  TableApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Create Table with HTTP info returned
  ///
  /// Create Table
  Future<Response> createTableWithHttpInfo(String authorization, String xAPIKey, Table body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/table".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Create Table
  ///
  /// Create Table
  Future<Table> createTable(String authorization, String xAPIKey, Table body) async {
    Response response = await createTableWithHttpInfo(authorization, xAPIKey, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Table') as Table;
    } else {
      return null;
    }
  }

  /// Delete Table By ID with HTTP info returned
  ///
  /// Delete Table By ID
  Future deleteTableByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/table/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'DELETE',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Delete Table By ID
  ///
  /// Delete Table By ID
  Future deleteTableByID(String authorization, String xAPIKey, String id) async {
    Response response = await deleteTableByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
    } else {
      return;
    }
  }

  /// Get Table List with HTTP info returned
  ///
  /// Get Table  List
  Future<Response> findTableWithHttpInfo(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }

    // create path and map variables
    String path = "/table".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(limit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "limit", limit));
    }
    if(offset != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "offset", offset));
    }
    if(sort != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sort", sort));
    }
    if(direction != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "direction", direction));
    }
    if(filter != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("multi", "filter", filter));
    }
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Table List
  ///
  /// Get Table  List
  Future<List<Table>> findTable(String authorization, String xAPIKey, { num limit, num offset, String sort, String direction, List<String> filter }) async {
    Response response = await findTableWithHttpInfo(authorization, xAPIKey,  limit: limit, offset: offset, sort: sort, direction: direction, filter: filter );
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return (apiClient.deserialize(_decodeBodyBytes(response), 'List<Table>') as List).map((item) => item as Table).toList();
    } else {
      return null;
    }
  }

  /// Get Table By ID with HTTP info returned
  ///
  /// Get Table By ID
  Future<Response> getTableByIDWithHttpInfo(String authorization, String xAPIKey, String id) async {
    Object postBody;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/table/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = [];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Get Table By ID
  ///
  /// Get Table By ID
  Future<Table> getTableByID(String authorization, String xAPIKey, String id) async {
    Response response = await getTableByIDWithHttpInfo(authorization, xAPIKey, id);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Table') as Table;
    } else {
      return null;
    }
  }

  /// Update Table By ID with HTTP info returned
  ///
  /// Update [object Object] By ID
  Future<Response> updateTableByIDWithHttpInfo(String authorization, String xAPIKey, String id, Table body) async {
    Object postBody = body;

    // verify required params are set
    if(authorization == null) {
     throw ApiException(400, "Missing required param: authorization");
    }
    if(xAPIKey == null) {
     throw ApiException(400, "Missing required param: xAPIKey");
    }
    if(id == null) {
     throw ApiException(400, "Missing required param: id");
    }
    if(body == null) {
     throw ApiException(400, "Missing required param: body");
    }

    // create path and map variables
    String path = "/table/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    headerParams["Authorization"] = authorization;
    headerParams["X-API-Key"] = xAPIKey;

    List<String> contentTypes = ["application/json"];

    String nullableContentType = contentTypes.isNotEmpty ? contentTypes[0] : null;
    List<String> authNames = ["JWT"];

    if(nullableContentType != null && nullableContentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
    }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             nullableContentType,
                                             authNames);
    return response;
  }

  /// Update Table By ID
  ///
  /// Update [object Object] By ID
  Future<Table> updateTableByID(String authorization, String xAPIKey, String id, Table body) async {
    Response response = await updateTableByIDWithHttpInfo(authorization, xAPIKey, id, body);
    if(response.statusCode >= 400) {
      throw ApiException(response.statusCode, _decodeBodyBytes(response));
    } else if(response.body != null) {
      return apiClient.deserialize(_decodeBodyBytes(response), 'Table') as Table;
    } else {
      return null;
    }
  }

}
