part of pointpos_api.api;

class QueryParam {
  String name;
  String value;

  QueryParam(this.name, this.value);
}

class ApiClient {

  String basePath;
  var client = Client();

  Map<String, String> _defaultHeaderMap = {};
  Map<String, Authentication> _authentications = {};

  final _regList = RegExp(r'^List<(.*)>$');
  final _regMap = RegExp(r'^Map<String,(.*)>$');

  ApiClient({this.basePath = "http://localhost"}) {
    // Setup authentications (key: authentication name, value: authentication).
    _authentications['APIKey'] = ApiKeyAuth("header", "X-API-Key");
    _authentications['JWT'] = ApiKeyAuth("header", "Authorization");
  }

  void addDefaultHeader(String key, String value) {
     _defaultHeaderMap[key] = value;
  }

  dynamic _deserialize(dynamic value, String targetType) {
    try {
      switch (targetType) {
        case 'String':
          return '$value';
        case 'int':
          return value is int ? value : int.parse('$value');
        case 'bool':
          return value is bool ? value : '$value'.toLowerCase() == 'true';
        case 'double':
          return value is double ? value : double.parse('$value');
        case 'Customer':
          return Customer.fromJson(value);
        case 'Discount':
          return Discount.fromJson(value);
        case 'Employee':
          return Employee.fromJson(value);
        case 'Exception':
          return Exception.fromJson(value);
        case 'ForbiddenException':
          return ForbiddenException.fromJson(value);
        case 'Gratuity':
          return Gratuity.fromJson(value);
        case 'Ingredient':
          return Ingredient.fromJson(value);
        case 'IngredientCategory':
          return IngredientCategory.fromJson(value);
        case 'IngredientCostOfGoodsSold':
          return IngredientCostOfGoodsSold.fromJson(value);
        case 'IngredientInventory':
          return IngredientInventory.fromJson(value);
        case 'InlineResponse200':
          return InlineResponse200.fromJson(value);
        case 'InternalServerErrorException':
          return InternalServerErrorException.fromJson(value);
        case 'Item':
          return Item.fromJson(value);
        case 'ItemCategory':
          return ItemCategory.fromJson(value);
        case 'ItemCostOfGoodsSold':
          return ItemCostOfGoodsSold.fromJson(value);
        case 'ItemInventory':
          return ItemInventory.fromJson(value);
        case 'ItemVariants':
          return ItemVariants.fromJson(value);
        case 'Login':
          return Login.fromJson(value);
        case 'LoyaltyProgram':
          return LoyaltyProgram.fromJson(value);
        case 'LoyaltyProgramPointFromBuyItem':
          return LoyaltyProgramPointFromBuyItem.fromJson(value);
        case 'LoyaltyProgramPointFromBuyItemEligibleCategories':
          return LoyaltyProgramPointFromBuyItemEligibleCategories.fromJson(value);
        case 'LoyaltyProgramPointFromBuyItemEligibleItems':
          return LoyaltyProgramPointFromBuyItemEligibleItems.fromJson(value);
        case 'LoyaltyProgramPointFromTotalSpent':
          return LoyaltyProgramPointFromTotalSpent.fromJson(value);
        case 'LoyaltyProgramRedeemRules':
          return LoyaltyProgramRedeemRules.fromJson(value);
        case 'MerchantAccount':
          return MerchantAccount.fromJson(value);
        case 'MerchantAccountBusinessInfo':
          return MerchantAccountBusinessInfo.fromJson(value);
        case 'MerchantAccountIdentification':
          return MerchantAccountIdentification.fromJson(value);
        case 'MerchantAccountPersonalDetails':
          return MerchantAccountPersonalDetails.fromJson(value);
        case 'MerchantAccountPersonalDetailsEmail':
          return MerchantAccountPersonalDetailsEmail.fromJson(value);
        case 'MerchantAccountPersonalDetailsPhone':
          return MerchantAccountPersonalDetailsPhone.fromJson(value);
        case 'MerchantAccountPublicProfile':
          return MerchantAccountPublicProfile.fromJson(value);
        case 'Modifier':
          return Modifier.fromJson(value);
        case 'ModifierOptions':
          return ModifierOptions.fromJson(value);
        case 'NotFoundException':
          return NotFoundException.fromJson(value);
        case 'Order':
          return Order.fromJson(value);
        case 'OrderCash':
          return OrderCash.fromJson(value);
        case 'OrderDiscounts':
          return OrderDiscounts.fromJson(value);
        case 'OrderItems':
          return OrderItems.fromJson(value);
        case 'OrderModifiers':
          return OrderModifiers.fromJson(value);
        case 'OrderPayments':
          return OrderPayments.fromJson(value);
        case 'OrderSentReceipts':
          return OrderSentReceipts.fromJson(value);
        case 'Outlet':
          return Outlet.fromJson(value);
        case 'OutletReceiptSettings':
          return OutletReceiptSettings.fromJson(value);
        case 'OutletReceiptSettingsOutletInfo':
          return OutletReceiptSettingsOutletInfo.fromJson(value);
        case 'Promo':
          return Promo.fromJson(value);
        case 'PromoPromoPeriod':
          return PromoPromoPeriod.fromJson(value);
        case 'PromoPromoPeriodDateRange':
          return PromoPromoPeriodDateRange.fromJson(value);
        case 'PromoPromoPeriodTimeRange':
          return PromoPromoPeriodTimeRange.fromJson(value);
        case 'PromoPromoPeriodWeekDay':
          return PromoPromoPeriodWeekDay.fromJson(value);
        case 'PromoRequirement':
          return PromoRequirement.fromJson(value);
        case 'PromoRequirementEligibleCategories':
          return PromoRequirementEligibleCategories.fromJson(value);
        case 'PromoRequirementEligibleItems':
          return PromoRequirementEligibleItems.fromJson(value);
        case 'PromoReward':
          return PromoReward.fromJson(value);
        case 'PromoRewardDiscount':
          return PromoRewardDiscount.fromJson(value);
        case 'PurchaseOrder':
          return PurchaseOrder.fromJson(value);
        case 'PurchaseOrderIngredients':
          return PurchaseOrderIngredients.fromJson(value);
        case 'Recipe':
          return Recipe.fromJson(value);
        case 'RecipeIngredients':
          return RecipeIngredients.fromJson(value);
        case 'Role':
          return Role.fromJson(value);
        case 'RolePermission':
          return RolePermission.fromJson(value);
        case 'SalesType':
          return SalesType.fromJson(value);
        case 'Signup':
          return Signup.fromJson(value);
        case 'Supplier':
          return Supplier.fromJson(value);
        case 'Table':
          return Table.fromJson(value);
        case 'TableGroup':
          return TableGroup.fromJson(value);
        case 'TableLocation':
          return TableLocation.fromJson(value);
        case 'Tax':
          return Tax.fromJson(value);
        case 'UnauthorizedException':
          return UnauthorizedException.fromJson(value);
        case 'Unit':
          return Unit.fromJson(value);
        case 'ValidationException':
          return ValidationException.fromJson(value);
        default:
          {
            Match match;
            if (value is List &&
                (match = _regList.firstMatch(targetType)) != null) {
              var newTargetType = match[1];
              return value.map((v) => _deserialize(v, newTargetType)).toList();
            } else if (value is Map &&
                (match = _regMap.firstMatch(targetType)) != null) {
              var newTargetType = match[1];
              return Map.fromIterables(value.keys,
                  value.values.map((v) => _deserialize(v, newTargetType)));
            }
          }
      }
    } on Exception catch (e, stack) {
      throw ApiException.withInner(500, 'Exception during deserialization.', e, stack);
    }
    throw ApiException(500, 'Could not find a suitable class for deserialization');
  }

  dynamic deserialize(String json, String targetType) {
    // Remove all spaces.  Necessary for reg expressions as well.
    targetType = targetType.replaceAll(' ', '');

    if (targetType == 'String') return json;

    var decodedJson = jsonDecode(json);
    return _deserialize(decodedJson, targetType);
  }

  String serialize(Object obj) {
    String serialized = '';
    if (obj == null) {
      serialized = '';
    } else {
      serialized = json.encode(obj);
    }
    return serialized;
  }

  // We don't use a Map<String, String> for queryParams.
  // If collectionFormat is 'multi' a key might appear multiple times.
  Future<Response> invokeAPI(String path,
                             String method,
                             Iterable<QueryParam> queryParams,
                             Object body,
                             Map<String, String> headerParams,
                             Map<String, String> formParams,
                             String nullableContentType,
                             List<String> authNames) async {

    _updateParamsForAuth(authNames, queryParams, headerParams);

    var ps = queryParams
      .where((p) => p.value != null)
      .map((p) => '${p.name}=${Uri.encodeQueryComponent(p.value)}');

    String queryString = ps.isNotEmpty ?
                         '?' + ps.join('&') :
                         '';

    String url = basePath + path + queryString;

    headerParams.addAll(_defaultHeaderMap);
    if (nullableContentType != null) {
      final contentType = nullableContentType;
      headerParams['Content-Type'] = contentType;
    }

    if(body is MultipartRequest) {
      var request = MultipartRequest(method, Uri.parse(url));
      request.fields.addAll(body.fields);
      request.files.addAll(body.files);
      request.headers.addAll(body.headers);
      request.headers.addAll(headerParams);
      var response = await client.send(request);
      return Response.fromStream(response);
    } else {
      var msgBody = nullableContentType == "application/x-www-form-urlencoded" ? formParams : serialize(body);
      final nullableHeaderParams = (headerParams.isEmpty)? null: headerParams;
      switch(method) {
        case "POST":
          return client.post(url, headers: nullableHeaderParams, body: msgBody);
        case "PUT":
          return client.put(url, headers: nullableHeaderParams, body: msgBody);
        case "DELETE":
          return client.delete(url, headers: nullableHeaderParams);
        case "PATCH":
          return client.patch(url, headers: nullableHeaderParams, body: msgBody);
        case "HEAD":
          return client.head(url, headers: nullableHeaderParams);
        default:
          return client.get(url, headers: nullableHeaderParams);
      }
    }
  }

  /// Update query and header parameters based on authentication settings.
  /// @param authNames The authentications to apply
  void _updateParamsForAuth(List<String> authNames, List<QueryParam> queryParams, Map<String, String> headerParams) {
    authNames.forEach((authName) {
      Authentication auth = _authentications[authName];
      if (auth == null) throw ArgumentError("Authentication undefined: " + authName);
      auth.applyToParams(queryParams, headerParams);
    });
  }

  T getAuthentication<T extends Authentication>(String name) {
    var authentication = _authentications[name];

    return authentication is T ? authentication : null;
  }
}
